@@ -355,6 +355,13 @@
    "Golan Heights (Israeli-occupied)"            => 1,
   );
 
+################################################################################
+# IANA (source of top level domains)
+
+%country_iana_orig =
+  (
+  );
+
 ################################################################################
 # CIA World Factbook (checks for codes)
 
@@ -385,6 +392,10 @@
                },
    "fips"   => {
                },
+   "dom"    => {"Gaza Strip"      => "-",
+                "West Bank"       => "-",
+                "Svalbard"        => "-",
+               },
   );
 
 1;
